function varargout = non_paramentic_pt_old(varargin)
% NON_PARAMENTIC_PT_OLD M-file for non_paramentic_pt_old.fig
%      NON_PARAMENTIC_PT_OLD, by itself, creates a new NON_PARAMENTIC_PT_OLD or raises the existing
%      singleton*.
%
%      H = NON_PARAMENTIC_PT_OLD returns the handle to a new NON_PARAMENTIC_PT_OLD or the handle to
%      the existing singleton*.
%
%      NON_PARAMENTIC_PT_OLD('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in NON_PARAMENTIC_PT_OLD.M with the given input arguments.
%
%      NON_PARAMENTIC_PT_OLD('Property','Value',...) creates a new NON_PARAMENTIC_PT_OLD or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before non_paramentic_pt_old_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to non_paramentic_pt_old_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help non_paramentic_pt_old

% Last Modified by GUIDE v2.5 04-Jan-2012 16:37:47

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @non_paramentic_pt_old_OpeningFcn, ...
                   'gui_OutputFcn',  @non_paramentic_pt_old_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before non_paramentic_pt_old is made visible.
function non_paramentic_pt_old_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to non_paramentic_pt_old (see VARARGIN)

% Choose default command line output for non_paramentic_pt_old
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes non_paramentic_pt_old wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = non_paramentic_pt_old_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function input_edit_Callback(hObject, eventdata, handles)
% hObject    handle to input_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of input_edit as text
%        str2double(get(hObject,'String')) returns contents of input_edit as a double


% --- Executes during object creation, after setting all properties.
function input_edit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to input_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function in_edit_Callback(hObject, eventdata, handles)
% hObject    handle to in_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of in_edit as text
%        str2double(get(hObject,'String')) returns contents of in_edit as a double


% --- Executes during object creation, after setting all properties.
function in_edit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to in_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function rest_edit_Callback(hObject, eventdata, handles)
% hObject    handle to rest_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of rest_edit as text
%        str2double(get(hObject,'String')) returns contents of rest_edit as a double


% --- Executes during object creation, after setting all properties.
function rest_edit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to rest_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in in_pushbutton.
function in_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to in_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
directoryname = uigetdir('C:\Users');
set(handles.in_edit,'String',directoryname);

% --- Executes on button press in re_pushbutton.
function re_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to re_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
directoryname = uigetdir('C:\Users');
set(handles.rest_edit,'String',directoryname);

% --- Executes on button press in analy_pushbutton.
function analy_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to analy_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
str1 = get(handles.input_edit,'String');
str2 = get(handles.in_edit,'String');
str3 = get(handles.rest_edit,'String');
if length(str1)<=0;
    errordlg('Input parameters can not be empty !')
 return;
end
if length(str2)<=0;
    errordlg('Input parameters can not be empty !')
 return;
end
if length(str3)<=0;
    errordlg('Storage address can not be empty !')
 return;
end
s1 =num2str( get(handles.non_checkbox,'Value'));
if s1=='1'
    
end




% --- Executes on button press in finish_pushbutton.
function finish_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to finish_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
delete(gcf);

% --- Executes on button press in input_pushbutton.
function input_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to input_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
directoryname = uigetdir('C:\Users');
set(handles.input_edit,'String',directoryname);


% --- Executes on button press in non_checkbox.
function non_checkbox_Callback(hObject, eventdata, handles)
% hObject    handle to non_checkbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of non_checkbox


% --- Executes on button press in getoneDegrees_pushbutton.
function getoneDegrees_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to getoneDegrees_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
str1 = get(handles.input_edit,'String');
str2 = get(handles.in_edit,'String');
str3 = get(handles.rest_edit,'String');
str4=strcat(str3,'\1');
str5=strcat(str3,'\2');
mkdir(str4);
mkdir(str5);
getoneDegrees(str1,str4);
getoneDegrees(str2,str5);
set(handles.input_edit,'String',str4);
set(handles.in_edit,'String',str5);
